@@ -13,6 +13,18 @@ but "does not seem to work", most likely you need to close ALL your Chrome
 windows. If you want Perl to share your browser, you will need to start Chrome
 yourself with the C<<--remote-debugging-port=9222>> command line switch.
 
+=head2 Tests fail with URLs that do not appear in the distribution files
+
+If you notice that tests ( most likely, C<t/51-mech-links.t> ) fail with
+URLs that are not on C<localhost> or C<127.0.0.1>, another not entirely unlikely
+explanation is that your machine or your browser has been infected by some
+"Search Plugin" redirector which exfiltrates your browsing history or redirects
+your search engine or banking websites to other websites.
+
+For confirmation and/or finding out how to remove the offender, maybe a
+search from a different machine for the URLs injected additionally into the
+test pages helps you identify the offender.
+
 =head1 OPERATION
 
 =head2 Chrome / Chromium best practices
@@ -26,6 +38,19 @@ Chrome / Chromium doesn't have an API for determining whether a download
 completed or not. Chrome versions v62 and v63 do have working downloads, but
 Chrome v64 does not send the appropriate API messages.
 
+=head2 Timeout when launching script while Chrome is running
+
+You get the error message
+
+  Timeout while connecting to localhost:9222. Do you maybe have a non-debug
+  instance of Chrome already running?
+
+Most likely you already launched the Chrome binary without supplying the
+C<--remote-debugging-port> option. Either stop all Chrome instances and
+(re)launch them using the C<--remote-debugging-port> on the command line or
+launch a separate Chrome session using a separate data directory using
+the C<data_directory> option.
+
 =head1 REPORTING AN ISSUE
 
 Ideally you ask your question on the public support forum, as then other people
@@ -63,5 +88,5 @@ This module is released under the same terms as Perl itself.
 =cut
 
 package WWW::Mechanize::Chrome::Troubleshooting;
-our $VERSION = '0.25';
+our $VERSION = '0.27';
 1;
